==> cl_appbase-0.0.6.tar.gz: lib/src/api/api_endpoint.dart <==
//TODO THIS IS LEGACY CODE, CAN PROBABLY BE REMOVED

import 'dart:typed_data';

import 'package:cl_datahub_common/common.dart';

/// Interface for api endpoints
abstract class ApiEndpoint<TData> {
  String get urlPostfix;
}

/// Represents an endpoint
/// TData should be chosen according to the data structure of the endpoint:
/// Plain -> String
/// Json -> Map<String, dynamic> / List<dynamic>
/// Byte Data -> UInt8List
/// class extending TransferObject
class _ApiEndpoint<TData> implements ApiEndpoint<TData> {
  final String urlPostfix;
  final bool requiresAuthentication;
  final DTOFactory? factory;

  const _ApiEndpoint(this.urlPostfix,
      {this.requiresAuthentication = false, this.factory});
}

/// Plain-text endpoint (ApiEndpoint<String>)
class PlainApiEndpoint extends _ApiEndpoint<String> {
  const PlainApiEndpoint(String urlPostfix,
      {bool requiresAuthentication = false})
      : super(urlPostfix, requiresAuthentication: requiresAuthentication);
}

/// ByteData endpoint (ApiEndpoint<Uint8List>)
class ByteApiEndpoint extends _ApiEndpoint<Uint8List> {
  const ByteApiEndpoint(String urlPostfix,
      {bool requiresAuthentication = false})
      : super(urlPostfix, requiresAuthentication: requiresAuthentication);
}

/// Json-Map endpoint (ApiEndpoint<Map<String, dynamic>>)
class JsonMapApiEndpoint extends _ApiEndpoint<Map<String, dynamic>> {
  const JsonMapApiEndpoint(String urlPostfix,
      {bool requiresAuthentication = false})
      : super(urlPostfix, requiresAuthentication: requiresAuthentication);
}

/// Json-List endpoint (ApiEndpoint<List<dynamic>>)
class JsonListApiEndpoint extends _ApiEndpoint<List<dynamic>> {
  const JsonListApiEndpoint(String urlPostfix,
      {bool requiresAuthentication = false})
      : super(urlPostfix, requiresAuthentication: requiresAuthentication);
}

/// Json-Map endpoint (ApiEndpoint<Map<String, dynamic>>)
class MapApiEndpoint<T extends TransferObject> extends _ApiEndpoint<T> {
  const MapApiEndpoint(String urlPostfix, DTOFactory<T> factory,
      {bool requiresAuthentication = false})
      : super(urlPostfix,
            factory: factory, requiresAuthentication: requiresAuthentication);
}

==> cl_appbase-0.0.46.tar.gz: lib/src/api/api_endpoint.dart <==
//TODO THIS IS LEGACY CODE, CAN PROBABLY BE REMOVED

import 'dart:typed_data';

import 'package:cl_datahub_common/common.dart';

/// Interface for api endpoints
abstract class ApiEndpoint<TData> {
  String get urlSuffix;
}

/// Represents an endpoint
/// TData should be chosen according to the data structure of the endpoint:
/// Plain -> String
/// Json -> Map<String, dynamic> / List<dynamic>
/// Byte Data -> UInt8List
/// class extending TransferObject
class _ApiEndpoint<TData> implements ApiEndpoint<TData> {
  final String urlSuffix;
  final bool requiresAuthentication;
  final DTOFactory? factory;

  const _ApiEndpoint(this.urlSuffix,
      {this.requiresAuthentication = false, this.factory});
}

/// Plain-text endpoint (ApiEndpoint<String>)
class PlainApiEndpoint extends _ApiEndpoint<String> {
  const PlainApiEndpoint(String urlSuffix,
      {bool requiresAuthentication = false})
      : super(urlSuffix, requiresAuthentication: requiresAuthentication);
}

/// ByteData endpoint (ApiEndpoint<Uint8List>)
class ByteApiEndpoint extends _ApiEndpoint<Uint8List> {
  const ByteApiEndpoint(String urlSuffix, {bool requiresAuthentication = false})
      : super(urlSuffix, requiresAuthentication: requiresAuthentication);
}

/// Json-Map endpoint (ApiEndpoint<Map<String, dynamic>>)
class JsonMapApiEndpoint extends _ApiEndpoint<Map<String, dynamic>> {
  const JsonMapApiEndpoint(String urlSuffix,
      {bool requiresAuthentication = false})
      : super(urlSuffix, requiresAuthentication: requiresAuthentication);
}

/// Json-List endpoint (ApiEndpoint<List<dynamic>>)
class JsonListApiEndpoint extends _ApiEndpoint<List<dynamic>> {
  const JsonListApiEndpoint(String urlSuffix,
      {bool requiresAuthentication = false})
      : super(urlSuffix, requiresAuthentication: requiresAuthentication);
}

/// Json-Map endpoint (ApiEndpoint<Map<String, dynamic>>)
class MapApiEndpoint<T extends TransferObject> extends _ApiEndpoint<T> {
  const MapApiEndpoint(String urlSuffix, DTOFactory<T> factory,
      {bool requiresAuthentication = false})
      : super(urlSuffix,
            factory: factory, requiresAuthentication: requiresAuthentication);
}
